@@ -11,11 +11,12 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
-from beartype.peps import resolve_pep563
 from beartype.roar import BeartypeDecorWrappeeException
 from beartype.typing import (
     Callable,
     Dict,
+    FrozenSet,
+    Optional,
 )
 from beartype._cave._cavefast import CallableCodeObjectType
 from beartype._cave._cavemap import NoneTypeOr
@@ -24,26 +25,27 @@ from beartype._check.checkmagic import (
     ARG_NAME_FUNC,
     ARG_NAME_RAISE_EXCEPTION,
 )
+from beartype._check.forward.fwdscope import BeartypeForwardScope
 from beartype._conf.confcls import BeartypeConf
 from beartype._data.hint.datahinttyping import (
     LexicalScope,
     TypeStack,
 )
-from beartype._util.func.utilfunccodeobj import (
-    get_func_codeobj,
-    # get_func_codeobj_or_none,
-)
-from beartype._util.func.utilfunctest import is_func_coro
-from beartype._util.func.utilfuncwrap import (
-    # unwrap_func_all,
-    unwrap_func_all_closures_isomorphic,
+from beartype._util.cache.pool.utilcachepoolobjecttyped import (
+    acquire_object_typed)
+from beartype._util.func.utilfunccodeobj import get_func_codeobj
+from beartype._util.func.utilfunctest import (
+    is_func_coro,
+    is_func_nested,
 )
+from beartype._util.func.utilfuncwrap import unwrap_func_all_closures_isomorphic
 
 # ....................{ CLASSES                            }....................
 class BeartypeCall(object):
     '''
-    **Beartype data** (i.e., object aggregating *all* metadata for the callable
-    currently being decorated by the :func:`beartype.beartype` decorator).**
+    **Beartype call metadata** (i.e., object encapsulating *all* metadata for
+    the user-defined callable currently being decorated by the
+    :func:`beartype.beartype` decorator).
 
     Design
     ----------
@@ -63,7 +65,7 @@ class BeartypeCall(object):
     memoized callables** (e.g.,
     :func:`beartype._check.code.codemake.make_func_wrapper_code`) **and
     higher-level callables** (e.g.,
-    :func:`beartype._decor._wrap.wrapmain.generate_code`). Instead, memoized
+    :func:`beartype._decor.wrap.wrapmain.generate_code`). Instead, memoized
     callables *must* return that state as additional return values up the call
     stack to those higher-level callables. By definition, memoized callables
     are *not* recalled on subsequent calls passed the same parameters. Since
@@ -80,8 +82,7 @@ class BeartypeCall(object):
     ----------
     cls_stack : TypeStack
         **Type stack** (i.e., either tuple of zero or more arbitrary types *or*
-        ``None``). Defaults to ``None``. See also the parameter of the same name
-        accepted by the
+        :data:`None`). See also the parameter of the same name accepted by the
         :func:`beartype._decor.decorcore.beartype_object` function for details.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
@@ -108,6 +109,53 @@ class BeartypeCall(object):
         For efficiency, this code object should *always* be accessed in lieu of
         inefficiently calling the comparatively slower
         :func:`beartype._util.func.utilfunccodeobj.get_func_codeobj` getter.
+    func_wrappee_is_nested : bool
+        Either:
+
+        * If this wrappee callable is **nested** (i.e., declared in the body of
+          another pure-Python callable or class), :data:`True`.
+        * If this wrappee callable is **global** (i.e., declared at module scope
+          in its submodule), :data:`False`.
+    func_wrappee_scope_forward : Optional[BeartypeForwardScope]
+        Either:
+
+        * If this wrappee callable is annotated by at least one **stringified
+          type hint** (i.e., declared as a :pep:`484`- or :pep:`563`-compliant
+          forward reference referring to an actual type hint that has yet to be
+          declared in the local and global scopes declaring this callable) that
+          :mod:`beartype` has already resolved to its referent, this wrappee
+          callable's **forward scope** (i.e., dictionary mapping from the name
+          to value of each locally and globally accessible attribute in the
+          local and global scope of this wrappee callable as well as deferring
+          the resolution of each currently undeclared attribute in that scope by
+          replacing that attribute with a forward reference proxy resolved only
+          when that attribute is passed as the second parameter to an
+          :func:`isinstance`-based runtime type-check).
+        * Else, :data:`None`.
+
+        Note that:
+
+        * The reconstruction of this scope is computationally expensive and thus
+          deferred until needed to resolve the first stringified type hint
+          annotating this wrappee callable.
+        * All callables have local scopes *except* global functions, whose local
+          scopes are by definition the empty dictionary.
+    func_wrappee_scope_nested_names : Optional[frozenset[str]]
+        Either:
+
+        * If this wrappee callable is annotated by at least one stringified type
+          hint that :mod:`beartype` has already resolved to its referent,
+          either:
+
+          * If this wrappee callable is **nested** (i.e., declared in the body
+            of another pure-Python callable or class), the non-empty frozen set
+            of the unqualified names of all parent callables lexically
+            containing this nested wrappee callable (including this nested
+            wrappee callable itself).
+          * Else, this wrappee callable is declared at global scope in its
+            submodule. In this case, the empty frozen set.
+
+        * Else, :data:`None`.
     func_wrappee_wrappee : Optional[Callable]
         Possibly unwrapped **decorated callable wrappee** (i.e., low-level
         callable wrapped by the high-level :attr:`func_wrappee` callable
@@ -135,21 +183,19 @@ class BeartypeCall(object):
           nor asynchronous generator), the ``"await "`` keyword.
     func_wrapper_code_signature_prefix : Optional[str]
         Code snippet prefixing the signature declaring the wrapper function
-        wrapping the decorated callable with type checking if the
-        :meth:`reinit` method has been called *or* ``None`` otherwise. If
-        non-``None``, this string is guaranteed to be either:
+        wrapping the decorated callable with type checking. Specifically, this
+        string is guaranteed to be either:
 
         * If the decorated callable is synchronous (i.e., neither a coroutine
           nor asynchronous generator), the empty string.
         * If the decorated callable is asynchronous (i.e., either a coroutine
-          nor asynchronous generator), the ``"async "`` keyword.
+          or asynchronous generator), the ``"async "`` keyword.
     func_wrapper_scope : LexicalScope
         **Local scope** (i.e., dictionary mapping from the name to value of
         each attribute referenced in the signature) of this wrapper function.
     func_wrapper_name : Optional[str]
         Machine-readable name of the wrapper function to be generated and
-        returned by this decorator if the :meth:`reinit` method has been called
-        *or* ``None`` otherwise.
+        returned by this decorator.
     '''
 
     # ..................{ CLASS VARIABLES                    }..................
@@ -162,10 +208,13 @@ class BeartypeCall(object):
         'conf',
         'func_arg_name_to_hint',
         'func_arg_name_to_hint_get',
-        'func_wrappee_codeobj',
-        'func_wrappee_wrappee_codeobj',
         'func_wrappee',
+        'func_wrappee_codeobj',
+        'func_wrappee_is_nested',
+        'func_wrappee_scope_forward',
+        'func_wrappee_scope_nested_names',
         'func_wrappee_wrappee',
+        'func_wrappee_wrappee_codeobj',
         'func_wrapper_code_call_prefix',
         'func_wrapper_code_signature_prefix',
         'func_wrapper_scope',
@@ -174,8 +223,8 @@ class BeartypeCall(object):
 
     # Coerce instances of this class to be unhashable, preventing spurious
     # issues when accidentally passing these instances to memoized callables by
-    # implicitly raising an "TypeError" exceptions on the first call to such a
-    # callable. There exists no tangible benefit to permitting these instances
+    # implicitly raising a "TypeError" exception on the first call to those
+    # callables. There exists no tangible benefit to permitting these instances
     # to be hashed (and thus also cached), since these instances are:
     # * Specific to the decorated callable and thus *NOT* safely cacheable
     #   across functions applying to different decorated callables.
@@ -209,6 +258,9 @@ class BeartypeCall(object):
         self.func_arg_name_to_hint_get: Callable[[str, object], object] = None  # type: ignore[assignment]
         self.func_wrappee: Callable = None  # type: ignore[assignment]
         self.func_wrappee_codeobj: CallableCodeObjectType = None  # type: ignore[assignment]
+        self.func_wrappee_is_nested: bool = None  # type: ignore[assignment]
+        self.func_wrappee_scope_forward: Optional[BeartypeForwardScope] = None
+        self.func_wrappee_scope_nested_names: Optional[FrozenSet[str]] = None
         self.func_wrappee_wrappee: Callable = None  # type: ignore[assignment]
         self.func_wrappee_wrappee_codeobj: CallableCodeObjectType = None  # type: ignore[assignment]
         self.func_wrapper_code_call_prefix: str = None  # type: ignore[assignment]
@@ -244,12 +296,10 @@ class BeartypeCall(object):
         conf : BeartypeConf
             Beartype configuration configuring :func:`beartype.beartype`
             specific to this callable.
-        cls_root : Optional[type]
-            **Root decorated class** if any or ``None`` otherwise. Defaults to
-            ``None``. See the class docstring for further details.
-        cls_curr : Optional[type]
-            **Current decorated class** if any or ``None`` otherwise. Defaults
-            to ``None``. See the class docstring for further details.
+        cls_stack : TypeStack
+            **Type stack** (i.e., either tuple of zero or more arbitrary types
+            *or* :data:`None`). See also the parameter of the same name accepted
+            by the :func:`beartype._decor.decorcore.beartype_object` function.
 
         Raises
         ----------
@@ -276,7 +326,7 @@ class BeartypeCall(object):
         #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
         # Avoid circular import dependencies.
-        from beartype._decor._error.errormain import get_beartype_violation
+        from beartype._decor.error.errormain import get_beartype_violation
 
         # If this callable is uncallable, raise an exception.
         if not callable(func):
@@ -298,7 +348,7 @@ class BeartypeCall(object):
 
         # If this class stack is *NOT* "None", this class stack is a tuple. In
         # this case, for each item of this class stack tuple...
-        if cls_stack is not None:
+        if cls_stack:
             for cls_stack_item in cls_stack:
                 # If this item is *NOT* a type, raise an exception.
                 if not isinstance(cls_stack_item, type):
@@ -310,18 +360,33 @@ class BeartypeCall(object):
         self.cls_stack = cls_stack
         self.conf = conf
 
-        # Possibly wrapped callable currently being decorated.
+        # Wrappee callable currently being decorated.
         self.func_wrappee = func
 
-        # Possibly unwrapped callable unwrapped from that callable.
-        # self.func_wrappee_wrappee = unwrap_func_all(func)
+        # Possibly unwrapped callable unwrapped from this wrappee callable.
         self.func_wrappee_wrappee = unwrap_func_all_closures_isomorphic(func)
+        # self.func_wrappee_wrappee = unwrap_func_all(func)
         # print(f'func_wrappee: {self.func_wrappee}')
         # print(f'func_wrappee_wrappee: {self.func_wrappee_wrappee}')
 
+        # True only if this wrappee callable is nested. As a minor efficiency
+        # gain, we can avoid the slightly expensive call to is_func_nested() by
+        # noting that:
+        # * If the class stack is non-empty, then this wrappee callable is
+        #   necessarily nested in one or more classes.
+        # * Else, defer to the is_func_nested() tester.
+        self.func_wrappee_is_nested = bool(cls_stack) or is_func_nested(func)
+
+        # Defer the resolution of both global and local scopes for this wrappee
+        # callable until needed to subsequently resolve stringified type hints.
+        self.func_wrappee_scope_forward = None
+        self.func_wrappee_scope_nested_names = None
+
         # Possibly wrapped callable code object.
         self.func_wrappee_codeobj = get_func_codeobj(
-            func=func, exception_cls=BeartypeDecorWrappeeException)
+            func=func,
+            exception_cls=BeartypeDecorWrappeeException,
+        )
 
         # Possibly unwrapped callable code object.
         self.func_wrappee_wrappee_codeobj = get_func_codeobj(
@@ -345,13 +410,6 @@ class BeartypeCall(object):
         # Machine-readable name of the wrapper function to be generated.
         self.func_wrapper_name = func.__name__
 
-        # Resolve all postponed hints on this callable if any *BEFORE* parsing
-        # the actual hints these postponed hints refer to.
-        resolve_pep563(
-            func=self.func_wrappee,
-            cls_stack=self.cls_stack,
-        )
-
         #FIXME: Globally replace all references to "__annotations__" throughout
         #the "beartype._decor" subpackage with references to this instead.
         #Since doing so is a negligible optimization, this is fine... for now.
@@ -411,6 +469,61 @@ class BeartypeCall(object):
             self.func_wrapper_code_call_prefix = ''
             self.func_wrapper_code_signature_prefix = ''
 
+# ....................{ FACTORIES                          }....................
+#FIXME: Unit test us up, please.
+def make_beartype_call(
+    # Mandatory parameters.
+    func: Callable,
+    conf: BeartypeConf,
+
+    # Variadic keyword parameters.
+    **kwargs
+) -> BeartypeCall:
+    '''
+    **Beartype call metadata** (i.e., object encapsulating *all* metadata for
+    the passed user-defined callable, typically currently being decorated by the
+    :func:`beartype.beartype` decorator).
+
+    Caveats
+    ----------
+    **This higher-level factory function should always be called in lieu of
+    instantiating the** :class:`.BeartypeCall` **class directly.** Why?
+    Brute-force efficiency. This factory efficiently reuses previously
+    instantiated :class:`.BeartypeCall` objects rather than inefficiently
+    instantiating new :class:`.BeartypeCall` objects.
+
+    **The caller must pass the metadata returned by this factory back to the**
+    :func:`beartype._util.cache.pool.utilcachepoolobjecttyped.release_object_typed`
+    **function.** If accidentally omitted, this metadata will simply be
+    garbage-collected rather than available for efficient reuse by this factory. 
+    Although hardly a worst-case outcome, omitting that explicit call largely
+    defeats the purpose of calling this factory in the first place.
+
+    Parameters
+    ----------
+    func : Callable
+        Callable to be described.
+    conf : BeartypeConf
+        Beartype configuration configuring :func:`beartype.beartype` uniquely
+        specific to this callable.
+
+    All remaining keyword parameters are passed as is to the
+    :meth:`.BeartypeCall.reinit` method.
+
+    Returns
+    ----------
+    BeartypeCall
+        Beartype call metadata describing this callable.
+
+    '''
+
+    # Previously cached callable metadata reinitialized from that callable.
+    bear_call = acquire_object_typed(BeartypeCall)
+    bear_call.reinit(func, conf, **kwargs)
+
+    # Return this metadata.
+    return bear_call
+
 # ....................{ GLOBALS ~ private                  }....................
 _TypeStackOrNone = NoneTypeOr[tuple]
 '''
