@@ -13,7 +13,7 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
-from beartype._data.datakind import ARG_NAME_RETURN
+from beartype._data.func.datafuncarg import ARG_NAME_RETURN
 from beartype._data.hint.datahinttyping import BeartypeableT
 from beartype._util.text.utiltextlabel import (
     label_callable,
@@ -60,7 +60,7 @@ def prefix_beartypeable(
 def prefix_beartypeable_pith(func: Callable, pith_name: str) -> str:
     '''
     Human-readable label describing either the parameter with the passed name
-    *or* return value if this name is ``return`` of the passed **beartypeable
+    *or* return value if this name is ``"return"`` of the passed **beartypeable
     callable** (i.e., callable wrapped by the :func:`beartype.beartype`
     decorator with a wrapper function type-checking that callable) suffixed by
     delimiting whitespace.
